@@ -29,9 +29,7 @@
 #include <vdkxdb2/vdkxcheckbutton.h>
 
 
-VDKXCheckButton::VDKXCheckButton(VDKForm* owner, 
-				 char* label = (char*) NULL, 
-				 char* tip = (char*) NULL):
+VDKXCheckButton::VDKXCheckButton(VDKForm* owner, char* label, char* tip ):
   VDKCheckButton(owner,label,tip), VDKXControl()
 {
 }
