@@ -35,7 +35,8 @@ VDKXCustomList::VDKXCustomList(VDKForm* owner,
 		 int columns,
 		 char** titles,
 		 GtkSelectionMode mode): 
-  VDKCustomList(owner,columns,titles,mode), VDKXControl()
+  VDKCustomList(owner,columns,titles,mode), VDKXControl(),
+  DateMode("DateMode",this,mmddyyyy)
 {
   fieldArray = FieldArray(columns);
 }
@@ -156,6 +157,7 @@ VDKXCustomList::PrepareTupleTh(
 			       char** tuple, 
 			       int z)
 {
+  int mode = DateMode;
   calendardate d;
   xbShort rc;
   char* buffer = NULL;
@@ -169,7 +171,7 @@ VDKXCustomList::PrepareTupleTh(
       switch(type)
 	{
 	case 'D':
-	  d = MakeDate(buffer);
+	  d = MakeDate(buffer,mode);
 	  strcpy(tuple[z], (char*) d);
 	  break;
 	case 'N':
