@@ -83,15 +83,24 @@ VDKXMemo::Write()
   if(table)
     {
       // writes memo field
-      char* p = NULL;
-      int l = Length;
-      if(l)
+      // char* p = NULL;
+      // int l = Length;
+      //      if(l)
+      //	{
+      char* p =  GetChars(0,-1);
+      if(p)
 	{
-	  p = new char[l+1];
-	  strcpy(p,GetChars(0,-1));
+	  int l = strlen(p); 
 	  rc = table->UpdateMemoData(field_id, l, p, F_SETLKW );
-	  delete[] p;
+	  g_free(p);
 	}
+      /*
+	p = new char[l+1];
+	strcpy(p,GetChars(0,-1));
+	rc = table->UpdateMemoData(field_id, l, p, F_SETLKW );
+	delete[] p;
+      */
     }
+  //    }
   return rc;
 }
