@@ -1,4 +1,24 @@
 
+/*
+Author:	
+E-mail:	
+*/
+/*
+License:
+	This program is free software; you can redistribute it and/or modify
+	it under the terms of the GNU General Public License as published by
+	the Free Software Foundation; either version 2 of the License, or
+	at your option any later version.
+*/
+
+/*
+Copyright  - 2003, all rights reserved
+*/
+
+/*
+** WARNING ** - File written by VDKBuilder, unuseful edit it
+*/
+
 #include <testxdb.h>
 //define static display type and initial form position
 GtkWindowType TestxdbForm::DisplayType = GTK_WINDOW_TOPLEVEL;
@@ -34,9 +54,10 @@ main form setup
 void
 TestxdbForm::GUISetup(void)
 {
-	SetSize(462,299);
+	SetSize(550,336);
 	Title = "testxdb Main Form";
 statusbar = new VDKStatusbar(this);
+gtk_widget_set_name (GTK_WIDGET(statusbar->WrappedWidget()), "statusbar");
 statusbar->SetSize(459,20);
 Add(statusbar,2,0,0,0);
 notebook = new VDKNotebook(this);
@@ -61,10 +82,12 @@ hbox17->Add(table2,0,1,1,0);
 vbox30 = new VDKBox(this,v_box);
 table2->AddToCell(vbox30,0,0);
 label4 = new VDKLabel(this,"First name:");
+gtk_widget_set_name (GTK_WIDGET(label4->WrappedWidget()), "label4");
 vbox30->Add(label4,0,1,1,0);
 vbox31 = new VDKBox(this,v_box);
 table2->AddToCell(vbox31,0,1);
 firstname = new VDKXEntry(this,15);
+gtk_widget_set_name (GTK_WIDGET(firstname->WrappedWidget()), "firstname");
 firstname->Editable = true;
 vbox31->Add(firstname,0,1,1,0);
 #ifdef VDKXDB_SUPPORT
@@ -80,10 +103,12 @@ firstname->AssignTableField(app->TheXdb(),(char*) dbname,"FIRSTNAME");
 vbox32 = new VDKBox(this,v_box);
 table2->AddToCell(vbox32,1,0);
 label5 = new VDKLabel(this,"Last name:");
+gtk_widget_set_name (GTK_WIDGET(label5->WrappedWidget()), "label5");
 vbox32->Add(label5,0,1,1,0);
 vbox33 = new VDKBox(this,v_box);
 table2->AddToCell(vbox33,1,1);
 lastname = new VDKXEntry(this,15);
+gtk_widget_set_name (GTK_WIDGET(lastname->WrappedWidget()), "lastname");
 lastname->Editable = true;
 vbox33->Add(lastname,0,1,1,0);
 #ifdef VDKXDB_SUPPORT
@@ -99,10 +124,12 @@ lastname->AssignTableField(app->TheXdb(),(char*) dbname,"LASTNAME");
 vbox34 = new VDKBox(this,v_box);
 table2->AddToCell(vbox34,2,0);
 label6 = new VDKLabel(this,"Birth date:");
+gtk_widget_set_name (GTK_WIDGET(label6->WrappedWidget()), "label6");
 vbox34->Add(label6,0,1,1,0);
 vbox35 = new VDKBox(this,v_box);
 table2->AddToCell(vbox35,2,1);
 birthdate = new VDKXEntry(this,10);
+gtk_widget_set_name (GTK_WIDGET(birthdate->WrappedWidget()), "birthdate");
 birthdate->Editable = true;
 vbox35->Add(birthdate,0,1,1,0);
 #ifdef VDKXDB_SUPPORT
@@ -118,10 +145,12 @@ birthdate->AssignTableField(app->TheXdb(),(char*) dbname,"BIRTHDATE");
 vbox36 = new VDKBox(this,v_box);
 table2->AddToCell(vbox36,3,0);
 label7 = new VDKLabel(this,"Sex:");
+gtk_widget_set_name (GTK_WIDGET(label7->WrappedWidget()), "label7");
 vbox36->Add(label7,0,1,1,0);
 vbox37 = new VDKBox(this,v_box);
 table2->AddToCell(vbox37,3,1);
 sex = new VDKXEntry(this,1);
+gtk_widget_set_name (GTK_WIDGET(sex->WrappedWidget()), "sex");
 sex->SetSize(160,21);
 sex->Editable = true;
 vbox37->Add(sex,0,1,1,0);
@@ -140,6 +169,7 @@ table2->AddToCell(vbox38,4,0);
 vbox39 = new VDKBox(this,v_box);
 table2->AddToCell(vbox39,4,1);
 ofage = new VDKXCheckButton(this,"Of age");
+gtk_widget_set_name (GTK_WIDGET(ofage->WrappedWidget()), "ofage");
 vbox39->Add(ofage,0,1,1,0);
 #ifdef VDKXDB_SUPPORT
 {
@@ -152,6 +182,7 @@ ofage->AssignTableField(app->TheXdb(),(char*) dbname,"OFAGE");
 }
 #endif
 memo = new VDKXMemo(this);
+gtk_widget_set_name (GTK_WIDGET(memo->WrappedWidget()), "memo");
 memo->SetSize(228,183);
 #ifdef VDKXDB_SUPPORT
 {
@@ -168,40 +199,51 @@ hbox16 = new VDKBox(this,h_box);
 hbox16->SetSize(455,26);
 notebook0_page0->Add(hbox16,0,0,0,0);
 hbox16->BorderWidth(0);
-nextButton = new VDKCustomButton(this,(char*) NULL,"Next",16,(GtkPositionType) 1);
+nextButton = new VDKCustomButton(this,(const char*) NULL,"Next",16,(GtkPositionType) 1);
+gtk_widget_set_name (GTK_WIDGET(nextButton->WrappedWidget()), "nextButton");
 nextButton->SetTip("Goes to next record");
 hbox16->Add(nextButton,0,1,1,0);
-prevButton = new VDKCustomButton(this,(char*) NULL,"Prev",16,(GtkPositionType) 1);
+prevButton = new VDKCustomButton(this,(const char*) NULL,"Prev",16,(GtkPositionType) 1);
+gtk_widget_set_name (GTK_WIDGET(prevButton->WrappedWidget()), "prevButton");
 prevButton->SetTip("Goes to previous record");
 hbox16->Add(prevButton,0,1,1,0);
-lastButton = new VDKCustomButton(this,(char*) NULL,"Last",16,(GtkPositionType) 1);
+lastButton = new VDKCustomButton(this,(const char*) NULL,"Last",16,(GtkPositionType) 1);
+gtk_widget_set_name (GTK_WIDGET(lastButton->WrappedWidget()), "lastButton");
 lastButton->SetTip("Goes to last record");
 hbox16->Add(lastButton,0,1,1,0);
-firstButton = new VDKCustomButton(this,(char*) NULL,"First",16,(GtkPositionType) 1);
+firstButton = new VDKCustomButton(this,(const char*) NULL,"First",16,(GtkPositionType) 1);
+gtk_widget_set_name (GTK_WIDGET(firstButton->WrappedWidget()), "firstButton");
 firstButton->SetTip("Goes to first record");
 hbox16->Add(firstButton,0,1,1,0);
-delButton = new VDKCustomButton(this,(char*) NULL,"Delete",16,(GtkPositionType) 1);
+delButton = new VDKCustomButton(this,(const char*) NULL,"Delete",16,(GtkPositionType) 1);
+gtk_widget_set_name (GTK_WIDGET(delButton->WrappedWidget()), "delButton");
 delButton->SetTip("Deletes current record");
 hbox16->Add(delButton,0,1,1,0);
-undelButton = new VDKCustomButton(this,(char*) NULL,"Undel",16,(GtkPositionType) 1);
+undelButton = new VDKCustomButton(this,(const char*) NULL,"Undel",16,(GtkPositionType) 1);
+gtk_widget_set_name (GTK_WIDGET(undelButton->WrappedWidget()), "undelButton");
 undelButton->SetTip("Undelete current record");
 hbox16->Add(undelButton,0,1,1,0);
 hbox21 = new VDKBox(this,h_box);
 notebook0_page0->Add(hbox21,0,0,0,0);
 hbox21->BorderWidth(0);
-showdelButton = new VDKCustomButton(this,(char*) NULL,"Show del",32,(GtkPositionType) 1);
+showdelButton = new VDKCustomButton(this,(const char*) NULL,"Show del",32,(GtkPositionType) 1);
+gtk_widget_set_name (GTK_WIDGET(showdelButton->WrappedWidget()), "showdelButton");
 showdelButton->SetTip("Show deleted records");
 hbox21->Add(showdelButton,0,1,1,0);
-updateButton = new VDKCustomButton(this,(char*) NULL,"Update",16,(GtkPositionType) 1);
+updateButton = new VDKCustomButton(this,(const char*) NULL,"Update",16,(GtkPositionType) 1);
+gtk_widget_set_name (GTK_WIDGET(updateButton->WrappedWidget()), "updateButton");
 updateButton->SetTip("Updates current record");
 hbox21->Add(updateButton,0,1,1,0);
-addButton = new VDKCustomButton(this,(char*) NULL,"Add",16,(GtkPositionType) 1);
+addButton = new VDKCustomButton(this,(const char*) NULL,"Add",16,(GtkPositionType) 1);
+gtk_widget_set_name (GTK_WIDGET(addButton->WrappedWidget()), "addButton");
 addButton->SetTip("Add a record");
 hbox21->Add(addButton,0,1,1,0);
-orderButton = new VDKCustomButton(this,(char*) NULL,"Switch order",16,(GtkPositionType) 1);
+orderButton = new VDKCustomButton(this,(const char*) NULL,"Switch order",16,(GtkPositionType) 1);
+gtk_widget_set_name (GTK_WIDGET(orderButton->WrappedWidget()), "orderButton");
 orderButton->SetTip("Switches between indexes");
 hbox21->Add(orderButton,0,1,1,0);
 quitButton = new VDKCustomButton(this,"mini-cross.xpm","_Quit",16,(GtkPositionType) 1);
+gtk_widget_set_name (GTK_WIDGET(quitButton->WrappedWidget()), "quitButton");
 quitButton->SetTip("Quit program");
 hbox21->Add(quitButton,0,1,1,0);
 notebook_page1 = new VDKBox(this,v_box);
@@ -212,8 +254,9 @@ char* fieldListTitles[] = {
 "Birth date",
 "Sex",
 "Amount",
-"Of Age" };
+"Of age" };
 fieldList = new VDKXCustomList(this,6,fieldListTitles,(GtkSelectionMode) 0);
+gtk_widget_set_name (GTK_WIDGET(fieldList->WrappedWidget()), "fieldList");
 fieldList->SetSize(100,100);
 fieldList->AutoResize = true;
 notebook_page1->Add(fieldList,0,1,1,0);
