@@ -1,3 +1,23 @@
+
+/*
+Author:	
+E-mail:	
+*/
+/*
+License:
+	This program is free software; you can redistribute it and/or modify
+	it under the terms of the GNU General Public License as published by
+	the Free Software Foundation; either version 2 of the License, or
+	at your option any later version.
+*/
+
+/*
+Copyright  - 2003, all rights reserved
+*/
+
+/*
+** WARNING ** - File written by VDKBuilder, unuseful edit it
+*/
 /*
 testxdb gui header
 */
